# Copyright 2006  Daniel Harple

require "enumerator"
require "svg2aamap/path_data"

module SVG2AAMap
  class Map
    
    def initialize
      @walls = []
      @zones = {}
    end
    
    attr_reader :zones
    
    def add_line(attrs)
      x1, y1, x2, y2 = attrs.values_at("x1", "y1", "x2", "y2").map { |o| Float(o) }
      wall = [x1, y1, x2, y2]
      @walls.push(wall)
      wall
    end
    
    def add_rect(attrs)
      x, y, w, h = attrs.values_at("x", "y", "width", "height").map { |o| Float(o) }
      wall = [x, y,
              x, y + h,
              x + w, y + h,
              x + w, y,
              x, y]
      @walls.push(wall)
      wall
    end
        
    def add_polyline(attrs)
      wall = attrs["points"].split(/[,\s]+/).map { |o| Float(o) }
      @walls.push(wall)
      wall
    end
    
    # polyline with a closepath
    def add_polygon(attrs)
      wall = add_polyline(attrs)
      @walls[-1] += wall[0..1] # close
      @walls[-1]
    end
    
    def add_circle(attrs, context)
      wall = attrs.values_at("cx", "cy", "r").map { |o| Float(o) }
      case context
      when :"win-zones", :"death-zones", :"fortress-zones"
        @zones[context] ||= []
        @zones[context] << wall
      end
      wall
    end
    
    def add_path(attrs)
      parser = SVG2AAMap::PathData.new
      data = attrs["d"]
      parsed = parser.parse(data)
      # $stderr.puts parsed.inspect
      if @walls[-1].nil? then @walls << [] end
      @walls[-1] += parsed
    end
        
    def to_s
      s = ""
      # a for “add”
      def s.a(other)
        self.concat(other + "\n")
      end
      s.a %(<!DOCTYPE Resource SYSTEM "AATeam/map-0.2.8.0_rc4.dtd">)
      s.a %(<Resource type="aamap" name="" version="" author="" category="">) 
      s.a %(\t<Map version="2">)
      s.a %(\t\t<World>)
      s.a %(\t\t\t<Field>)
      
      @zones.each do |effect, shape_circles|
        effect = effect.to_s.gsub("-zones", "")
        shape_circles.each do |o|
          s.a %(\t\t\t\t<Zone effect="#{effect}">)
          s.a %(\t\t\t\t\t<ShapeCircle radius="#{o[2]}">)
          s.a %(\t\t\t\t\t\t<Point x="#{o[0]}" y="#{-o[1]}"/>)
          s.a %(\t\t\t\t\t</ShapeCircle>)
          s.a %(\t\t\t\t</Zone>) 
        end
      end

      @walls.each do |wall|
        s.a %(\t\t\t\t<Wall>)
        # Flip y-axis for arma
        wall.each_slice(2) { |o| s.a %(\t\t\t\t\t<Point x="#{o[0]}" y="#{-o[1]}"/>) }
        s.a %(\t\t\t\t</Wall>)
      end
      s.a %(\t\t\t</Field>)
      s.a %(\t\t</World>)
      s.a %(\t</Map>)
      s.a %(</Resource>)
      s
    end
        
  end
end