# Copyright 2006  Daniel Harple

require "rexml/document"
require "rexml/streamlistener"
require "English"

module SVG2AAMap
  class Listener
    
    include REXML::StreamListener
    
    def initialize(map)
      @map = map
      @context = nil
      @context_level = 0
    end
        
    # Handles how elements are added to the map. For example a SVG circle
    # element will be handled different when no context is set than compared
    # to when <tt>:win-zones</tt> context is set.
    attr_reader :context
    
    # When in a context group, allow the user to use groups. The current level
    # of contexts must be kept track of.
    attr_reader :context_level
    
    def tag_start(name, attrs)
      case name
      when "line"
        @map.add_line(attrs)

      when "rect"
        @map.add_rect(attrs)
        
      when "polyline"
        @map.add_polyline(attrs)
        
      when "polygon"
        @map.add_polygon(attrs)
        
      when "g"
        case attrs["id"]
        when /win-zones/i, /death-zones/i, /fortress-zones/i
          @context = $MATCH.downcase.to_sym
          @context_level = 1
        else
          # Allow user to use groups in a context
          @context_level += 1 if @context
        end
        
      when "circle"
        @map.add_circle(attrs, @context)
      
      when "path"
        @map.add_path(attrs)
      end
    end
    
    def tag_end(name)
      case name
      when "g"
        @context_level -= 1 if @context
        @context = nil if @context_level == 0
      end
    end

    def entitydecl(namespace, uri)
    end

  end
  
  class Parser
    def initialize(file)
      @map = SVG2AAMap::Map.new
      REXML::Document.parse_stream(file, Listener.new(@map))
    end
    
    attr_reader :map
  end
end