require "test/unit"
require "svg2aamap"

class TestMap < Test::Unit::TestCase
  
  def setup
    @map = SVG2AAMap::Map.new
  end

  def test_add_rect_should_convert_attrs_to_float
    wall = @map.add_rect({"x" => "1", "y" => "2", "width" => "3", "height" => "4.0"})
    wall.each do |o| assert_instance_of(Float, o) end
  end
  
  def test_add_line
    wall = @map.add_line({"x1" => "0", "y1" => "0", "x2" => "100", "y2" => "100"})
    assert_equal([0.0, 0.0,
                  100.0, 100.0], wall)
  end
  
  def test_add_rect_expands_rect_into_points
    wall = @map.add_rect({"x" => "0", "y" => "0", "width" => "10", "height" => "15"})
    assert_equal([0.0, 0.0,
                  0.0, 15.0,
                  10.0, 15.0,
                  10.0, 0.0,
                  0.0, 0.0], wall)
  end
  
  def test_add_polyline_parses_points
    wall = @map.add_polyline({"points" => "0,0 0, 100 \n100 , 200"})
    assert_equal([0.0, 0.0,
                  0.0, 100.0,
                  100.0, 200.0],  wall)
  end
  
  def test_add_polygon_closes_path
    wall = @map.add_polygon({"points" => "0,0 0,100, 100,100"})
    assert_equal([0.0, 0.0,
                  0.0, 100.0,
                  100.0, 100.0,
                  0.0, 0.0], wall)
  end
  
  def test_add_circle_should_respect_context
    circle = @map.add_circle({"cx" => 0, "cy" => 0, "r" => 3}, :"death-zones")
    assert_equal({:"death-zones" => [[0.0, 0.0, 3.0]]}, @map.zones)
  end
end