require "test/unit"
require "svg2aamap"

begin
  require "rubygems"
rescue LoadError
end
require "flexmock"

class TestListener < Test::Unit::TestCase
  include FlexMock::TestCase
  
  def setup
    @map = flexmock("map")
    @listener = SVG2AAMap::Listener.new(@map)
  end
  
  def test_includes_streamlistener
    assert_equal(true, SVG2AAMap::Listener.ancestors.include?(REXML::StreamListener))
  end
  
  def test_line_start
    @map.should_receive(:add_line).once
    @listener.tag_start("line", {})
  end
    
  def test_rect_start
    @map.should_receive(:add_rect).once
    @listener.tag_start("rect", {})
  end
  
  def test_polyline_start
    @map.should_receive(:add_polyline).once
    @listener.tag_start("polyline", {})
  end
  
  def test_polygon_start
    @map.should_receive(:add_polygon).once
    @listener.tag_start("polygon", {})
  end
  
  def test_circle_start
    @map.should_receive(:add_circle).once
    @listener.tag_start("circle", {})
  end
  
end

class TestListenerGroupContext < Test::Unit::TestCase
  include FlexMock::TestCase
  
  def setup
    @map = flexmock("map")
    @listener = SVG2AAMap::Listener.new(@map)
  end
  
  def test_tag_start_set_context
    @listener.tag_start("g", {"id" => "Win-zones"})
    assert_equal(:"win-zones", @listener.context)
    assert_equal(1, @listener.context_level)
  end
  
  def tag_end_reduces_context_when_set
    @listener.tag_start("g", {"id" => "Win-zones"})
    @listener.tag_end("g")
    assert_equal(nil, @listener.context)
    assert_equal(0, @listener.context_level)
  end
  
  def test_unknown_id_does_not_set_context
    @listener.tag_start("g", {"id" => "foo"})
    assert_equal(nil, @listener.context)
    assert_equal(0, @listener.context_level)
  end
  
  def test_in_context_allows_groups
    @listener.tag_start("g", {"id" => "Win-zones"})
    @listener.tag_start("g", {"id" => "blah"})
    assert_equal(:"win-zones", @listener.context)
    assert_equal(2, @listener.context_level)
    
    @listener.tag_end("g")
    assert_equal(1, @listener.context_level)
    assert_equal(:"win-zones", @listener.context)
    
    @listener.tag_end("g")
    assert_equal(0, @listener.context_level)
    assert_equal(nil, @listener.context)
  end
  
end
