require "test/unit"
require "svg2aamap"

class TestPathDataParsing < Test::Unit::TestCase
  
  def setup
    @path_data = SVG2AAMap::PathData.new
  end
  
  def test_data_is_split_into_tokens
    data = @path_data.tokenize("M 100 100 L 300 100 L 200,300 z")
    assert_equal(%w(M 100 100 L 300 100 L 200 300 z), data)
  end
  
  def test_float_parsing
    parsed = @path_data.parse("M 0.0 10.3")
    assert_equal([0.0, 10.3], parsed)
  end
  
  def test_scientific_notation_parsing
    parsed = @path_data.parse("M 0.0 10.3e10")
    assert_equal([0.0, Float("10.3e10")], parsed)
  end

  def test_parsing_close_paths
    parsed = @path_data.parse("M 100 100 z")
    assert_equal([100.0, 100.0,
                  100.0, 100.0], parsed)
  end
    
  def test_parsing_absolute_lines
    parsed = @path_data.parse("M 100 100 L 300 100 L 200,300 z")
    assert_equal([100.0, 100.0, 
                  300.0, 100.0,
                  200.0, 300.0, 
                  100.0, 100.0], parsed)
  end
  
  def test_relative_lineto
    parsed = @path_data.parse("M 100 100 l 10 15")
    assert_equal([100.0, 100.0,
                  110.0, 115.0], parsed)    
  end
end